<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>CreateBlock</name>
    <message>
        <location filename="../CreateBlock.js" line="+51"/>
        <source>Reference Point</source>
        <translation>Referenční bod</translation>
    </message>
    <message>
        <location filename="../CreateBlockInit.js" line="+2"/>
        <source>&amp;Create Block from Selection</source>
        <translation>&amp;Vytvořit blok z výběru</translation>
    </message>
</context>
</TS>
